@@ -539,7 +539,7 @@ class HyperbolicGeodesic(SageObject):
     def is_parallel(self, other):
         r"""
         Return ``True`` if the two given hyperbolic geodesics are either
-        ultra parallel or asymptotically parallel and``False`` otherwise.
+        ultra parallel or asymptotically parallel and ``False`` otherwise.
 
         INPUT:
 
@@ -1212,12 +1212,22 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: UHP.get_geodesic(1 + I, 2 + 4*I).ideal_endpoints()
             [Boundary point in UHP -sqrt(65) + 9,
              Boundary point in UHP sqrt(65) + 9]
-        """
 
+        TESTS:
+
+        Check that :issue:`32362` is fixed::
+
+            sage: PD = HyperbolicPlane().PD()
+            sage: z0 = CC(-0.0571909584179366 + 0.666666666666667*I)
+            sage: z1 = CC(-1)
+            sage: pts = PD.get_geodesic(z0, z1).ideal_endpoints()
+            sage: pts[1]
+            Boundary point in PD I
+        """
         start = self._start.coordinates()
         end = self._end.coordinates()
-        [x1, x2] = [real(k) for k in [start, end]]
-        [y1, y2] = [imag(k) for k in [start, end]]
+        x1, x2 = real(start), real(end)
+        y1, y2 = imag(start), imag(end)
         M = self._model
         # infinity is the first endpoint, so the other ideal endpoint
         # is just the real part of the second coordinate
@@ -1227,7 +1237,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         if CC(end).is_infinity():
             return [M.get_point(x1), M.get_point(end)]
         # We could also have a vertical line with two interior points
-        if x1 == x2:
+        if abs(x1 - x2) < EPSILON:
             return [M.get_point(x1), M.get_point(infinity)]
         # Otherwise, we have a semicircular arc in the UHP
         c = ((x1+x2)*(x2-x1) + (y1+y2)*(y2-y1)) / (2*(x2-x1))
@@ -1854,9 +1864,9 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: g = HyperbolicPlane().UHP().get_geodesic(1, 1 + I)
             sage: h = HyperbolicPlane().UHP().get_geodesic(-sqrt(2), sqrt(2))
             sage: g.angle(h)
-            arccos(1/2*sqrt(2))
+            1/4*pi
             sage: h.angle(g)
-            arccos(1/2*sqrt(2))
+            1/4*pi
 
         Angle is unoriented, as opposed to oriented. ::
 
@@ -2046,8 +2056,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             Full MatrixSpace of 2 by 2 dense matrices over Complex Field
             with 53 bits of precision
         """
-
-        [s, e] = [k.coordinates() for k in self.complete().endpoints()]
+        s, e = [k.coordinates() for k in self.complete().endpoints()]
         B = HyperbolicGeodesicUHP._get_B(p)
         # outmat below will be returned after we normalize the determinant.
         outmat = B * HyperbolicGeodesicUHP._crossratio_matrix(s, p, e)
@@ -2351,12 +2360,14 @@ class HyperbolicGeodesicHM(HyperbolicGeodesic):
         # This means that cosh(x)*v1 + sinh(x)*v2 is unit timelike.
         hyperbola = tuple(cosh(x)*v1 + sinh(x)*v2)
         endtime = arcsinh(v2_ldot_u2)
-        # mimic the function _parametric_plot3d_curve using a bezier3d instead of a line3d
-        # this is required in order to be able to plot hyperbolic polygons whithin the plot library
+        # mimic the function _parametric_plot3d_curve using a bezier3d
+        # instead of a line3d
+        # this is required in order to be able to plot hyperbolic
+        # polygons within the plot library
         g, ranges = setup_for_eval_on_grid(hyperbola, [(x, 0, endtime)], points)
         f_x, f_y, f_z = g
-        points = [(f_x(u), f_y(u), f_z(u)) for u in xsrange(*ranges[0], include_endpoint=True)]
-        return points
+        return [(f_x(u), f_y(u), f_z(u))
+                for u in xsrange(*ranges[0], include_endpoint=True)]
 
     def plot(self, show_hyperboloid=True, **graphics_options):
         r"""
